pyrelic
--------------------

pyrelic is a python module that wraps the RELIC cryptography library.
RELIC performs high-performance elliptic curve cryptography and pairing-based
elliptic curves. pyrelic also includes verifiable pseudorandom functions
used in Pythia.
